# Icinga1 configuration objects upgrader

This tool permit to convert Icinga1 configuration objects to Icinga2 compatible format.

There is no one-to-one convertission method, so this tool try to make it as the best possible.

## Installation

```
git clone https://gitlab.easter-eggs.com/brenard/icinga1_objects_upgrader.git /usr/local/src/icinga1_objects_upgrader
ln -s /usr/local/src/icinga1_objects_upgrader/main.py /usr/local/bin/icinga1_objects_upgrader
```

## Usage

```
usage: icinga1_objects_upgrader [-h] [-v] [-d] [-l LOGFILE] [-i INPUT]
                                [-o OUTPUT] [--map-command MAP_COMMANDS]

optional arguments:
  -h, --help            show this help message and exit
  -v, --verbose         Enable verbose mode
  -d, --debug           Enable debug mode
  -l LOGFILE, --log-file LOGFILE
                        Log file path
  -i INPUT, --input INPUT
                        Icinga object config directory path to parse
  -o OUTPUT, --output OUTPUT
                        Icinga object config directory path to parse
  --map-command MAP_COMMANDS
                        Icinga1 command name mapping for Icinga2. Could be use
                        to map for instance 'check-host-alive_4' Icinga1
                        check_command to Icinga2 'ping4' CheckCommand. For
                        this example, you have to specify --map-command check-
                        host-alive_4=ping4
```

__Example:__
```
icinga1_objects_upgrader -v \
	-i /etc/icinga1/objects \
	-o /etc/icing2/conf.d \
	--map-command check-host-alive_4=ping4 \
	--map-command check_smtp=smtp \
	--map-command check_ssh=ssh
```

## Define notifications

More than other concept, notifications have been completly redesign in Icinga2 and it's really not possible to convert it one-to-one:
- _contact_ & _contactgroup_ are now _User_ and _UserGroup_ objects
- their is no notification parameter in _Host_ and _Service_ definition (excepted _enable_notifications_ parameter)
- User's notification parameters change a lot:
  - _host_notifications_enabled_ and _service_notifications_enabled_ parameters are replaced by an unique _enable_notifications_ parameter
  - _host_notification_period_ and _service_notification_period_ parameters are replaced by an unique _period_ parameter
  - _host_notification_options_ and _service_notification_options_ parameters are replaced by similar _states_ and _types_ parameters
  - _host_notification_commands_ and _service_notification_commands_ parameters are removed and notification command are now define in _Notification_ object
- _Notification_ objects now regroup parameter about notifications send to users

To make migration easier, I try to implement a solution to migration configuration, I put old _contacts_, _contact_groups_, _notification_interval_, _notification_period_, _notifications_options_ and _first_notification_delay_ of _Host_ and _Service_ objects to a _notifications_ variable. This permit to use it to dynamically configured _Notification_ objects. The following example permit to email notifications to users:

```
template Notification "generic-notification" {
  command = "mail-service-notification"
  period = "24x7"
  interval = 1h

  types = [ Problem, Acknowledgement, Recovery, Custom, FlappingStart,
            FlappingEnd, DowntimeStart, DowntimeEnd, DowntimeRemoved ]

  users = [ "icingaadmin" ]
}

template Notification "generic-host-notification" {
  import "generic-notification"

  if (host.vars.notifications.users || host.vars.notifications.groups) {
    if (host.vars.notifications.users) {
      users = host.vars.notifications.users
    } else {
      users = []
    }
    if (host.vars.notifications.groups) {
      user_groups = host.vars.notifications.groups
    } else {
      user_groups = []
    }
  }

  if (host.vars.notifications.states) {
    states = host.vars.notifications.states
  } else {
    states = [ Up, Down ]
  }

  if (host.vars.notifications.types) {
    types = host.vars.notifications.types
  }

  if (host.vars.notifications.period) {
    period = host.vars.notifications.period
  }

  if (host.vars.notifications.interval) {
    interval = host.vars.notifications.interval
  }

  if (host.vars.notifications.delay) {
    times.begin = host.vars.notifications.delay
  }
}

template Notification "generic-service-notification" {
  import "generic-notification"

  if (service.vars.notifications.users || service.vars.notifications.groups) {
    if (service.vars.notifications.users) {
      users = service.vars.notifications.users
    } else {
      users = []
    }
    if (service.vars.notifications.groups) {
      user_groups = service.vars.notifications.groups
    } else {
      user_groups = []
    }
  }

  if (service.vars.notifications.states) {
    states = service.vars.notifications.states
  } else {
    states = [ Warning, Critical, Unknown ]
  }

  if (service.vars.notifications.types) {
    types = service.vars.notifications.types
  }

  if (service.vars.notifications.period) {
    period = service.vars.notifications.period
  }

  if (service.vars.notifications.interval) {
    interval = service.vars.notifications.interval
  }

  if (service.vars.notifications.delay) {
    times.begin = service.vars.notifications.delay
  }
}

apply Notification "notify-by-mail" to Host {
  import "generic-host-notification"

  assign where match("*", host.name) && host.enable_notifications
}

apply Notification "notify-by-mail" to Service {
  import "generic-service-notification"

  assign where match("*", service.name) && service.enable_notifications
}
```

__Note:__
- https://icinga.com/docs/icinga2/latest/doc/23-migrating-from-icinga-1x/#manual-config-migration-hints-for-notifications
- https://icinga.com/docs/icinga2/latest/doc/03-monitoring-basics/#notifications-users-from-hostservice

## Copyright

Copyright (c) 2020 Benjamin Renard / Easter-eggs


## License

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 3 as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
